# SemClip requires Soprano and Nepomuk, so this module checks for those too.
#
# Once done this will define
#
#  SEMCLIP_FOUND       - system has SemClip
#  SEMCLIP_INCLUDE_DIR - the SemClip include directory
#  SEMCLIP_LIBRARIES   - link these to use SemClip
#  SEMCLIP_DEFINITIONS - compiler switches required for using SemClip
#

if ( NOT DEFINED Soprano_FOUND )
  macro_optional_find_package( Soprano )
  macro_log_feature( Soprano_FOUND "Soprano" "Semantic Desktop Storing" "" FALSE "" "Soprano is needed for SemClip" )
endif ( NOT DEFINED Soprano_FOUND )

if ( NOT DEFINED Nepomuk_FOUND )
  macro_optional_find_package( Nepomuk )
  macro_log_feature( Nepomuk_FOUND "Nepomuk" "Nepomuk" "http://www.kde.org" FALSE "" "Nepomuk is needed for SemClip" )
endif ( NOT DEFINED Nepomuk_FOUND )


if ( Soprano_FOUND AND Nepomuk_FOUND )

  set( SEMCLIP_FIND_REQUIRED ${SemClip_FIND_REQUIRED} )

  if ( SEMCLIP_INCLUDE_DIR AND SEMCLIP_LIBRARIES )

    # Already in cache, be silent
    set( SEMCLIP_FIND_QUIETLY TRUE )

  else ( SEMCLIP_INCLUDE_DIR AND SEMCLIP_LIBRARIES )

    find_path( SEMCLIP_INCLUDE_DIR
      NAMES
      semclip/semclip.h
      PATHS
      ${KDE4_INCLUDE_DIR}
      ${INCLUDE_INSTALL_DIR}
    )

    find_library( SEMCLIP_LIBRARIES
      NAMES
      semclip
      PATHS
      ${KDE4_LIB_DIR}
      ${LIB_INSTALL_DIR}
    )

    mark_as_advanced( SEMCLIP_INCLUDE_DIR SEMCLIP_LIBRARIES )

  endif ( SEMCLIP_INCLUDE_DIR AND SEMCLIP_LIBRARIES )

  include( FindPackageHandleStandardArgs )
  find_package_handle_standard_args( SemClip DEFAULT_MSG
                                     SEMCLIP_LIBRARIES SEMCLIP_INCLUDE_DIR )

endif ( Soprano_FOUND AND Nepomuk_FOUND )
